@@ -35,6 +35,9 @@ class jobs:
     Polly CLI jobs can now be initiated, managed and have a status-checked for from Polly Python.
     This lets users run jobs on the Polly cloud infrastructure by scaling computation resources as per need.
     Users can start and stop tasks and even monitor jobs.
+
+    Note:- User must use TOKEN instead of KEYS to work with the job module of polly-python.
+
     Args:
         token (str): token copy from polly.
     Usage:
@@ -61,26 +64,45 @@ class jobs:
     # project_id -> workspace_id
     # job_file -> json file
     @Track.track_decorator
-    def submit_job(self, project_id: str, job_file: str) -> pd.DataFrame:
+    def submit_job(self, project_id: str, job_file=None, job_dict=None) -> pd.DataFrame:
         """
         Submits  a polly cli job in the given workspace.
         A message will be displayed on the status of the operation.
+        Job configuration can be provided either as a json file using job_file parameter or
+        as a dictionary using job_dict parameter
 
         Args:
             project_id (str):  workspace id
-            job_file (str): required configuration json file path
+            job_file (str, optional) : job configuration json file path, defaults to None
+            job_dict (dict, optional) : job configuration dictionary, defaults to None
         """
         parameter_check_dict = {}
+
         parameter_check_dict["project_id"] = project_id
-        parameter_check_dict["job_file"] = job_file
+        # neither both job_file and job_dict should be provided, nor both should not be provided.
+        # only one of the two should be provided
+        if (job_file is None and job_dict is None) or (job_file and job_dict):
+            raise InvalidParameterException(
+                "One of json_file or json_dict required for the function."
+                + "Either both or none have been provided.Please check"
+            )
+        if job_file:
+            parameter_check_dict["job_file"] = job_file
+        if job_dict:
+            parameter_check_dict["job_dict"] = job_dict
+
         self._parameter_check_for_jobs(parameter_check_dict)
         if isinstance(project_id, int):
             project_id = str(project_id)
 
         try:
-            with open(job_file, "r") as jobfile:
-                jobData = json.load(jobfile)
-                # self._validate_job_json(jobData)
+            if job_file:
+                with open(job_file, "r") as jobfile:
+                    jobData = json.load(jobfile)
+                    # self._validate_job_json(jobData)
+            else:
+                jobData_json_string = json.dumps(job_dict)
+                jobData = json.loads(jobData_json_string)
         except Exception as err:
             raise err
 
@@ -574,12 +596,8 @@ class jobs:
                     and (isinstance(project_id, str) or isinstance(project_id, int))
                 ):
                     raise InvalidParameterException("project id/workspace id")
-            elif keys == "job_file":
-                job_file = values
-                if not (job_file):
-                    raise InvalidParameterException("job_file")
-                if not os.path.exists(job_file):
-                    raise InvalidPathException(job_file)
+            elif keys in ["job_file", "job_dict"]:
+                self._check_job_configuration_parameter(keys, values)
             elif keys == "job_id":
                 job_id = values
                 self._check_job_id(job_id, project_id)
@@ -590,6 +608,20 @@ class jobs:
                         f"valid mode values are : {DATA_LOG_MODES}"
                     )
 
+    def _check_job_configuration_parameter(
+        self, job_config_param_key, job_config_param_value
+    ):
+        if job_config_param_key == "job_file":
+            job_file = job_config_param_value
+            if not os.path.exists(job_file):
+                raise InvalidPathException(job_file)
+        elif job_config_param_key == "job_dict":
+            job_dict = job_config_param_value
+            if not (isinstance(job_dict, dict)):
+                raise InvalidParameterException(
+                    "job_dict should be a dictionary datatype"
+                )
+
     def _check_job_id(self, job_id, project_id):
         if not (job_id and (isinstance(job_id, str))):
             raise InvalidParameterException("Missing/invalid datatype for job id")
