@@ -2,6 +2,7 @@ from requests import Session
 import os
 import base64
 import json
+import warnings
 
 
 class PollySession(Session):
@@ -44,6 +45,7 @@ class PollySession(Session):
         else:
             version = version + "/local"
 
+        self.token = TOKEN
         # check to differentiate between api auth key and refresh token
         # this check is based on the premise that
 
@@ -70,6 +72,13 @@ class PollySession(Session):
                 "Cookie": f"refreshToken={TOKEN}",
                 "User-Agent": "polly-python/" + version,
             }
+            warnings.formatwarning = lambda msg, *args, **kwargs: f"WARNING: {msg}\n"
+            warnings.warn(
+                "**Important Update**: We're making our authentication method more convenient. "
+                + "By 1st September 2023, we'll completely transition to the new authentication method, "
+                + "discontinuing the use of refresh tokens. Please use KEYS going forward instead of TOKEN"
+            )
+            print("\n")
         except Exception:
             self.headers = {
                 "Content-Type": "application/vnd.api+json",
