@@ -69,7 +69,7 @@ def test_omixatlas_summary():
     Polly.auth(token)
     nobj1 = omixatlas.OmixAtlas()
     obj1 = omixatlas.OmixAtlas(token)
-    key = "elucidata.liveromix_atlas"
+    key = "liveromix_atlas"
     assert obj1.omixatlas_summary(key)["data"] is not None
     assert nobj1.omixatlas_summary(key)["data"] is not None
 
